@@ -1,5 +1,5 @@
 package PAUSE::Users;
-$PAUSE::Users::VERSION = '0.09';
+$PAUSE::Users::VERSION = '0.11';
 # ABSTRACT: interface to PAUSE's users file (00whois.xml)
 
 use strict;
@@ -8,7 +8,6 @@ use warnings;
 use MooX::Role::CachedURL 0.04;
 
 use Moo;
-use PAUSE::Users::User;
 use PAUSE::Users::UserIterator;
 with 'MooX::Role::CachedURL';
 
@@ -44,7 +43,7 @@ PAUSE::Users - interface to PAUSE's users file (00whois.xml)
  my $users    = PAUSE::Users->new(max_age => '1 day');
  my $iterator = $users->user_iterator();
 
- while (defined($user = $iterator->next_user)) {
+ while (defined(my $user = $iterator->next_user)) {
    print "PAUSE id = ", $user->id, "\n";
    print "Name     = ", $user->fullname, "\n";
  }
